<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="da">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../cmd.cpp" line="141"/>
        <source>Administrator Access Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../cmd.cpp" line="142"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Livemiljø registreret. Vælg venligst rodpartitionen på
 det system du vil ændre (der vises kun Linux-partitioner)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Brug forenklet menustruktur uden undermenuer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Brug flade menuer (ingen undermenuer)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Opstart til</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Indstil til &apos;0&apos; for at opstarte med det samme uden at vise menuen, eller til &apos;-1&apos; for at vente uendeligt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Timeout for menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Kerneparametre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Når valgmuligheden er aktiveret, så gemmes det du vælger fra grub-opstartsmenuen som den nye standard til fremtidige opstarter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Aktivér husk sidst valgte opstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Baggrund</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Billede</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Aktivér tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Billede</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Forhåndsvis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Meddelelser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Meget detaljeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Detaljeret (standardindstilling)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Begrænset</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Vis log</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Afslut programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Anvend</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>Still running</source>
        <translation>Kører stadig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <location filename="../mainwindow.cpp" line="381"/>
        <location filename="../mainwindow.cpp" line="415"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <location filename="../mainwindow.cpp" line="1346"/>
        <location filename="../mainwindow.cpp" line="1359"/>
        <location filename="../mainwindow.cpp" line="1365"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Installer opstartsbillede, vent venligst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>Updating sources</source>
        <translation>Opdaterer kilder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Could not install the bootsplash.</source>
        <translation>Kunne ikke installere opstartsbilledet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Could not create a temporary folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>Cannot continue</source>
        <translation>Kan ikke fortsætte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="556"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Kan ikke oprette chroot-miljø, kan ikke ændre opstartsvalgmuligheder. Afslutter...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="887"/>
        <location filename="../mainwindow.cpp" line="1266"/>
        <source>Updating configuration, please wait</source>
        <translation>Opdaterer konfiguration, vent venligst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="958"/>
        <source>Updating initramfs...</source>
        <translation>Opdaterer initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="972"/>
        <location filename="../mainwindow.cpp" line="1281"/>
        <source>Updating grub...</source>
        <translation>Opdaterer grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="998"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1000"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program til at være almindelige opstartsvalg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1002"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1003"/>
        <source>%1 License</source>
        <translation>%1-licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1024"/>
        <source>%1 Help</source>
        <translation>%1-hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1034"/>
        <location filename="../mainwindow.cpp" line="1243"/>
        <source>Running in a Virtual Machine</source>
        <translation>Kører i en virtuel maskine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1035"/>
        <location filename="../mainwindow.cpp" line="1244"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Dit nuværende system kører i en virtuel maskine,
Plymouth-opstartsbillede virker på en begrænset måde og du vil heller ikke være i stand til at forhåndsvise temaet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1042"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth-pakker ikke installeret</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1043"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth-pakker er ikke installeret.
Er det OK at fortsætte og installere dem?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Billeder (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1211"/>
        <source>Log not found</source>
        <translation>Log ikke fundet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1211"/>
        <source>Could not find log at </source>
        <translation>Kunne ikke finde log i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1346"/>
        <source>Could not retrieve UUID for %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1354"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Indtast adgangskode for at låse op for %1-krypteret partition:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1359"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1365"/>
        <source>Could not open %1 LUKS container</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1200"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <source>Live System Detected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Live System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="172"/>
        <source>Installed System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>Failed to update package sources.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Installing packages:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Success</source>
        <translation>Det lykkedes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Bootsplash installed successfully.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Failed to create temporary file.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="982"/>
        <source>Your changes have been successfully applied.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="983"/>
        <source>Operation Complete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1068"/>
        <source>Select image to display in bootloader</source>
        <translation>Vælg billede som skal vises i opstartsindlæser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1192"/>
        <source>Boot Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1232"/>
        <source>Needs reboot</source>
        <translation>Behøver genstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1233"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth blev lige installeret, det kan være nødvendigt at genstarte inden du kan vise forhåndsvisninger</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1302"/>
        <source>Click to select theme</source>
        <translation>Klik for at vælge tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1313"/>
        <source>Select GRUB theme</source>
        <translation>Vælg GRUB-tema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program til at være almindelige opstartsvalg</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="55"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="56"/>
        <location filename="../about.cpp" line="65"/>
        <source>Changelog</source>
        <translation>Ændringslog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="57"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>